@@ -227,6 +227,21 @@ export default function getConfigTemplate (): ConfigOptions {
       zoomBehavior: 'gui' // Used to determine what gets zoomed: The GUI or the editor
     },
     checkForBeta: false, // Should the user be notified of beta releases?
+    displayToolbarButtons: {
+      showOpenPreferencesButton: true,
+      showNewFileButton: true,
+      showPreviousFileButton: true,
+      showNextFileButton: true,
+      showToggleReadabilityButton: true,
+      showMarkdownCommentButton: true,
+      showMarkdownLinkButton: true,
+      showMarkdownImageButton: true,
+      showMarkdownMakeTaskListButton: true,
+      showInsertTableButton: true,
+      showInsertFootnoteButton: true,
+      showDocumentInfoText: true,
+      showPomodoroButton: true
+    },
     uuid: uuid4() // The app's unique anonymous identifier
   }
 }
